@@ -2,9 +2,9 @@
 
 import socketio,pyperclip,time,argparse
 
-__version__ = "v0.0.23"
+__version__ = "v0.0.25"
 # standard Python
-sio = socketio.Client()
+sio = socketio.Client(reconnection=True, reconnection_attempts=0, reconnection_delay=5, reconnection_delay_max=60)
 @sio.event
 def connect():
     print("I'm connected!")
@@ -33,17 +33,18 @@ def main():
     server = args.server
     room = args.id
     access_token=args.access_token
-    sio.connect(url=server,auth={"room":room,"access_token":access_token})
+    sio.connect(url=server,auth={"room":room,"access_token":access_token},wait=True,wait_timeout=60*5)
 
     curr_clip = pyperclip.paste()
 
     while True:
-        new_clip = pyperclip.paste()
+        new_clip = pyperclip.waitForNewPaste()
+        print("new_clip:{}".format(new_clip))
         if new_clip != curr_clip:
             if not new_clip.startswith("file:///"):
-                sio.emit('sync',{"data":new_clip, "room":room})
+                # 一个很有意思的BUG,如果下一段代码是 sio.emit('sync',{"data":new_clip, "room":room}),在windows上剪贴板会被系统清空，但把“data”改成“data123”之类的就没事
+                sio.emit('sync',{"clipboard_content":new_clip, "room":room})
             curr_clip = new_clip
-        time.sleep(0.5)
 def cli() -> None:
     try:
         main()
